@@ -1,7 +1,7 @@
 """URLs for the ``django-user-media`` app."""
 from django.conf.urls.defaults import patterns, url
 
-from user_media.views import CreateImageView, DeleteImageView
+from user_media.views import CreateImageView, DeleteImageView, UpdateImageView
 
 
 urlpatterns = patterns('',
@@ -15,6 +15,11 @@ urlpatterns = patterns('',
         name='user_media_image_create',
     ),
 
+    url(r'^image/(?P<pk>\d+)/$',
+        UpdateImageView.as_view(),
+        name='user_media_image_edit',
+    ),
+
     url(r'^image/(?P<pk>\d+)/delete/$',
         DeleteImageView.as_view(),
         name='user_media_image_delete',
